A numeric data frame or matrix with the x values in the
first column followed by one or more columns of y values.
main
The title for the plot.
xlab,ylab
x and y axis labels for the plot.
xat
Where to put the optional xaxlabs.
xaxlab
Optional labels for the x positions.
ylim
Optional y limits.
lty
Line type for the polygon borders.
border
Color for the polygon borders.
col
Color to fill the polygons.
staxx
Whether to call staxlab to stagger the x axis labels.
axis4
Whether to display the right ordinate on the plot.
...
Additional arguments passed to plot.
Value
nil
Details
stackpoly is similar to a line plot with the area under the
lines filled with color(s). Ideally, each successive set of y values
(columns 2 to n of x) is greater than the values in the previous set
so that the polygons form a rising series of crests.